summaryrefslogtreecommitdiffstats
path: root/tqdbusobjectpath.h
diff options
context:
space:
mode:
Diffstat (limited to 'tqdbusobjectpath.h')
-rw-r--r--tqdbusobjectpath.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqdbusobjectpath.h b/tqdbusobjectpath.h
index 6f0bd5b..119e1f8 100644
--- a/tqdbusobjectpath.h
+++ b/tqdbusobjectpath.h
@@ -72,10 +72,10 @@ public:
* TQT_DBusObjectPath grandChildNode(childNode, "grandchild"); // => "/child/grandchild"
* @endcode
*
* @param tqparentNode the object path to create the child on
* @param nodeName the name of the child node
*/
- TQT_DBusObjectPath(const TQT_DBusObjectPath& tqparentNode, const TQCString& nodeName);
+ TQT_DBusObjectPath(const TQT_DBusObjectPath& parentNode, const TQCString& nodeName);
/**
* @brief Returns whether the current content is considered a valid object path
@@ -97,7 +97,7 @@ public:
* @return the tqparent node's object path or an empty and invalid object
* if this is already the root node
*/
- TQT_DBusObjectPath tqparentNode() const;
+ TQT_DBusObjectPath parentNode() const;
/**
* @brief Checks the given string for validity as a D-Bus object path
@@ -72,10 +72,10 @@ public:
* @endcode
*
- * @param tqparentNode the object path to create the child on
+ * @param parentNode the object path to create the child on
* @param nodeName the name of the child node
*/